clear all
figure(1)
clf

%% initialize

Ab=1000*1000^2; %m^2, area of basin
a=4; %degrees, spread angle of basin
b=0.5; %runoff coefficient 
E=2.4; %m/yr, evaporation rate
P=0.1; %m/yr, precipitation
H0 = 0; %initial height of water in the lake


% time array
dt = 1; % in years
tmax = 1000;
t = 0:dt:tmax;
imax = length(t);

%filling of arrays and setting up initial conditions
H = zeros(size(t));
Al = zeros(size(t));
V=zeros(size(t));
H(1) = H0; % fills in 1st array element in H
Al(1)=pi*(H(1)/tand(a))^2;
V(1) = (1/3)*Al(1)*tand(a)*(Al(1)/pi)^(1/2); %initial volume



%% run

for i=2:imax
    dVdt=(P-E)*Al(i-1)+b*P*(Ab-Al(i-1));
    V(i) = V(i-1) + (dVdt*dt);
    V(i) = max(0,V(i)); %disallows negative volumes in the bucket
    H(i) = (3*V(i)*(tand(a))^2/pi)^(1/3);
    Al(i) = pi*(H(i)/tand(a))^2;
end

%% finalize

figure(1)
subplot(3,1,1)
plot(t,V)

set(gca,'fontsize',14,'fontname','arial')
ylabel('Volume(m^3)','fontname','arial','fontsize',18)

subplot(3,1,2)
plot(t,H,'linewidth',2)

set(gca,'fontsize',14,'fontname','arial')
ylabel('Height (m)','fontname','arial','fontsize', 18)

subplot(3,1,3)
plot(t,Al,'r')
ylabel('Area of Lake (m)','fontname','arial','fontsize',18)


